@@ -172,6 +172,7 @@ def test_replace_response(memory_jobstore):
     assert response.replace.jobs[-1].uuid == test_job.uuid
     assert response.replace.jobs[-1].metadata == metadata
     assert response.replace.jobs[-1].output_schema == "123"
+    assert response.replace.output is not None
 
     # replace with flow with multi outputs
     test_job = Job(replace_flow_multioutput, metadata=metadata, output_schema="123")
@@ -181,6 +182,7 @@ def test_replace_response(memory_jobstore):
     assert response.replace.jobs[-1].uuid == test_job.uuid
     assert response.replace.jobs[-1].metadata == metadata
     assert response.replace.jobs[-1].output_schema == "123"
+    assert response.replace.output is not None
 
     # replace with list of flow
     test_job = Job(replace_list_flow, metadata=metadata, output_schema="123")
@@ -448,7 +450,8 @@ def test_job_decorator():
 def test_response():
     # no need to test init as it is just a dataclass, instead test from_job_returns
     # test no job returns
-    from jobflow import Schema
+    from pydantic import BaseModel
+
     from jobflow.core.job import Response
 
     response = Response.from_job_returns(None)
@@ -480,7 +483,7 @@ def test_response():
         Response.from_job_returns([response_original, 5])
 
     # test schema
-    class MySchema(Schema):
+    class MySchema(BaseModel):
         number: int
         name: str
 
@@ -744,9 +747,11 @@ def test_update_maker_kwargs():
 
 
 def test_output_schema(memory_jobstore):
-    from jobflow import Job, Response, Schema, job
+    from pydantic import BaseModel
 
-    class AddSchema(Schema):
+    from jobflow import Job, Response, job
+
+    class AddSchema(BaseModel):
         result: int
 
     @job(output_schema=AddSchema)
